/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 


#ifndef _UTILS_H
#define _UTILS_H


gint run_dialog(gchar *title, gchar *message, gchar *action_message);
void run_dialog_error(gchar *title, gchar *msg);
gint run_dialog_information(gchar *title, gchar *msg);
gboolean check_url_already_exists(gchar *checkurl);
gboolean check_server_already_exists(gchar *checkurl);



#endif
